@@ -1,5 +1,5 @@
 # Relational
-# Copyright (C) 2008-2020  Salvo "LtWorf" Tomaselli
+# Copyright (C) 2008-2023  Salvo "LtWorf" Tomaselli
 #
 # Relation is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,27 +18,30 @@
 #
 # Stuff non-related to relational algebra, but used for maintenance.
 
-import http.client
-import urllib.parse
 import os.path
 import pickle
 import base64
 from typing import Optional, Tuple
+from gettext import gettext as _
 
 from relational.relation import Relation
 from relational import parser
 from relational.rtypes import is_valid_relation_name
 
 
-SWEARWORDS = {'fuck', 'shit', 'suck', 'merda', 'mierda', 'merde'}
-
-
-def send_survey(data) -> int:
+def send_survey(data: dict[str, str]) -> int:
     '''Sends the survey. Data must be a dictionary.
     returns the http response.
 
     returns 0 in case of error
     returns -1 in case of swearwords'''
+    import urllib.parse
+    from http.client import HTTPSConnection
+    import ssl
+
+
+    # Scan for swearwords
+    SWEARWORDS = {'fuck', 'shit', 'suck', 'merda', 'mierda', 'merde'}
 
     post = ''
     for i in data.keys():
@@ -50,14 +53,21 @@ def send_survey(data) -> int:
             return -1
 
     # sends the string
-    params = urllib.parse.urlencode({'survey': post})
-    headers = {"Content-type":
-               "application/x-www-form-urlencoded", "Accept": "text/plain"}
-    connection = http.client.HTTPConnection('feedback-ltworf.appspot.com')
+    headers = {
+        "Accept": "text/plain",
+        "X-Survey": "relational",
+    }
+    for k, v in data.items():
+        headers[f'X-Survey-{k}'] = v
+    connection = HTTPSConnection(
+        'tomaselli.page',
+        context = ssl._create_unverified_context() # Of course python can't find the root cert
+    )
+
     try:
-        connection.request("POST", "/feedback/relational", params, headers)
+        connection.request("GET", "feedback.py", headers=headers)
         return connection.getresponse().status
-    except:
+    except Exception:
         return 0
 
 
@@ -65,19 +75,17 @@ def check_latest_version() -> Optional[str]:
     '''Returns the latest version available.
     Heavely dependent on server and server configurations
     not granted to work forever.'''
-    connection = http.client.HTTPConnection('feedback-ltworf.appspot.com')
+    import json
+    import urllib.request
+
     try:
-        connection.request("GET", "/version/relational")
-        r = connection.getresponse()
+        req = urllib.request.Request('https://api.github.com/repos/ltworf/relational/releases')
+        with urllib.request.urlopen(req) as f:
+            data = json.load(f)
+        return data[0]['name']
     except:
         return None
 
-    # html
-    s = r.read()
-    if len(s) == 0:
-        return None
-    return s.decode().strip()
-
 
 class UserInterface:
 
@@ -95,7 +103,7 @@ class UserInterface:
         Files ending with .csv are loaded as csv, the others are
         loaded as json.
         '''
-        if filename.endswith('.csv'):
+        if filename.lower().endswith('.csv'):
             rel = Relation.load_csv(filename)
         else:
             rel = Relation.load(filename)
@@ -107,7 +115,7 @@ class UserInterface:
 
     def store(self, filename: str, name: str) -> None:
         '''Stores a relation to file.'''
-        if filename.endswith('.csv'):
+        if filename.lower().endswith('.csv'):
             self.relations[name].save_csv(filename)
         else:
             self.relations[name].save(filename)
@@ -156,7 +164,7 @@ class UserInterface:
     def set_relation(self, name: str, rel: Relation) -> None:
         '''Sets the relation corresponding to name.'''
         if not is_valid_relation_name(name):
-            raise Exception('Invalid name for destination relation')
+            raise Exception(_('Invalid name for destination relation'))
         self.relations[name] = rel
 
     def suggest_name(self, filename: str) -> Optional[str]:
@@ -187,7 +195,7 @@ class UserInterface:
         relname is not None, adds the result to the
         dictionary, with the name given in relname.'''
         if not is_valid_relation_name(relname):
-            raise Exception('Invalid name for destination relation')
+            raise Exception(_('Invalid name for destination relation'))
 
         expr = parser.parse(query)
         result = expr(self.relations)
@@ -229,10 +237,10 @@ class UserInterface:
             try:
                 r = self.execute(query, relname)
             except Exception as e:
-                raise Exception('Error in query: %s\n%s' % (
+                raise Exception(_('Error in query: %s\n%s') % (
                     query,
                     str(e)
                 ))
         if r is None:
-            raise Exception('No query executed')
+            raise Exception(_('No query executed'))
         return r
